| Type: | Package |
| Title: | Point-and-Click GUI Client for 'dqcheckr' |
| Version: | 0.1.0 |
| Date: | 2026-06-18 |
| Description: | A graphical user interface for the 'dqcheckr' package. Provides a point-and-click 'shiny' application for configuring dataset quality checks, running them against recurring file deliveries, and browsing historical check results — without writing any R code. |
| License: | MIT + file LICENSE |
| URL: | https://github.com/mickmioduszewski/dqcheckrGUI |
| BugReports: | https://github.com/mickmioduszewski/dqcheckrGUI/issues |
| Encoding: | UTF-8 |
| Language: | en-GB |
| Depends: | R (≥ 4.2) |
| Imports: | dqcheckr (≥ 0.2.2), shiny, bslib, shinyvalidate, shinyFiles, shinyAce, reactable, DT, callr, yaml, readr, DBI, RSQLite, stats, tools |
| Suggests: | testthat (≥ 3.1.0), knitr, rmarkdown, shinytest2, withr |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-06-18 20:36:58 UTC; mick |
| Author: | Mick Mioduszewski [aut, cre] |
| Maintainer: | Mick Mioduszewski <mick@mioduszewski.net> |
| Repository: | CRAN |
| Date/Publication: | 2026-06-24 08:20:13 UTC |
Launch the dqcheckrGUI Shiny application
Description
Opens the point-and-click interface for configuring and running dqcheckr dataset quality checks.
Usage
run_app(...)
Arguments
... |
Arguments passed to |
Value
Called for its side effect; does not return a value.
Examples
if (interactive()) {
run_app()
}